# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/mavros_msgs/msg/sys_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/humble/mavros_msgs/msg/sys_status.proto\x12+make87_messages_ros2.humble.mavros_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xae\x03\n\tSysStatus\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x17\n\x0fsensors_present\x18\x03 \x01(\r\x12\x17\n\x0fsensors_enabled\x18\x04 \x01(\r\x12\x16\n\x0esensors_health\x18\x05 \x01(\r\x12\x0c\n\x04load\x18\x06 \x01(\r\x12\x17\n\x0fvoltage_battery\x18\x07 \x01(\r\x12\x17\n\x0f\x63urrent_battery\x18\x08 \x01(\x05\x12\x19\n\x11\x62\x61ttery_remaining\x18\t \x01(\x05\x12\x16\n\x0e\x64rop_rate_comm\x18\n \x01(\r\x12\x13\n\x0b\x65rrors_comm\x18\x0b \x01(\r\x12\x15\n\rerrors_count1\x18\x0c \x01(\r\x12\x15\n\rerrors_count2\x18\r \x01(\r\x12\x15\n\rerrors_count3\x18\x0e \x01(\r\x12\x15\n\rerrors_count4\x18\x0f \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.mavros_msgs.msg.sys_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SYSSTATUS']._serialized_start=200
  _globals['_SYSSTATUS']._serialized_end=630
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NewMqtt2RosBridgeRequest(_message.Message):
    __slots__ = ["header", "ros_topic", "mqtt_topic", "primitive", "mqtt_qos", "ros_queue_size", "ros_latched"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS_TOPIC_FIELD_NUMBER: _ClassVar[int]
    MQTT_TOPIC_FIELD_NUMBER: _ClassVar[int]
    PRIMITIVE_FIELD_NUMBER: _ClassVar[int]
    MQTT_QOS_FIELD_NUMBER: _ClassVar[int]
    ROS_QUEUE_SIZE_FIELD_NUMBER: _ClassVar[int]
    ROS_LATCHED_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros_topic: str
    mqtt_topic: str
    primitive: bool
    mqtt_qos: int
    ros_queue_size: int
    ros_latched: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros_topic: _Optional[str] = ..., mqtt_topic: _Optional[str] = ..., primitive: bool = ..., mqtt_qos: _Optional[int] = ..., ros_queue_size: _Optional[int] = ..., ros_latched: bool = ...) -> None: ...

class NewMqtt2RosBridgeResponse(_message.Message):
    __slots__ = ["header", "success"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ...) -> None: ...



from make87_messages_ros2.jazzy.rc_common_msgs.msg import return_code_pb2 as _return_code_pb2
from make87_messages_ros2.jazzy.rc_reason_msgs.msg import region_of_interest2_d_pb2 as _region_of_interest2_d_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetRegionOfInterest2DRequest(_message.Message):
    __slots__ = ["region_of_interest_2d"]
    REGION_OF_INTEREST_2D_FIELD_NUMBER: _ClassVar[int]
    region_of_interest_2d: _region_of_interest2_d_pb2.RegionOfInterest2D
    def __init__(self, region_of_interest_2d: _Optional[_Union[_region_of_interest2_d_pb2.RegionOfInterest2D, _Mapping]] = ...) -> None: ...

class SetRegionOfInterest2DResponse(_message.Message):
    __slots__ = ["return_code"]
    RETURN_CODE_FIELD_NUMBER: _ClassVar[int]
    return_code: _return_code_pb2.ReturnCode
    def __init__(self, return_code: _Optional[_Union[_return_code_pb2.ReturnCode, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import laser_echo_pb2 as _laser_echo_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MultiEchoLaserScan(_message.Message):
    __slots__ = ["header", "ros2_header", "angle_min", "angle_max", "angle_increment", "time_increment", "scan_time", "range_min", "range_max", "ranges", "intensities"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    ANGLE_MIN_FIELD_NUMBER: _ClassVar[int]
    ANGLE_MAX_FIELD_NUMBER: _ClassVar[int]
    ANGLE_INCREMENT_FIELD_NUMBER: _ClassVar[int]
    TIME_INCREMENT_FIELD_NUMBER: _ClassVar[int]
    SCAN_TIME_FIELD_NUMBER: _ClassVar[int]
    RANGE_MIN_FIELD_NUMBER: _ClassVar[int]
    RANGE_MAX_FIELD_NUMBER: _ClassVar[int]
    RANGES_FIELD_NUMBER: _ClassVar[int]
    INTENSITIES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    angle_min: float
    angle_max: float
    angle_increment: float
    time_increment: float
    scan_time: float
    range_min: float
    range_max: float
    ranges: _containers.RepeatedCompositeFieldContainer[_laser_echo_pb2.LaserEcho]
    intensities: _containers.RepeatedCompositeFieldContainer[_laser_echo_pb2.LaserEcho]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., angle_min: _Optional[float] = ..., angle_max: _Optional[float] = ..., angle_increment: _Optional[float] = ..., time_increment: _Optional[float] = ..., scan_time: _Optional[float] = ..., range_min: _Optional[float] = ..., range_max: _Optional[float] = ..., ranges: _Optional[_Iterable[_Union[_laser_echo_pb2.LaserEcho, _Mapping]]] = ..., intensities: _Optional[_Iterable[_Union[_laser_echo_pb2.LaserEcho, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/nav_msgs/srv/get_plan.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.rolling.nav_msgs.msg import path_pb2 as make87__messages__ros2_dot_rolling_dot_nav__msgs_dot_msg_dot_path__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/rolling/nav_msgs/srv/get_plan.proto\x12)make87_messages_ros2.rolling.nav_msgs.srv\x1a\x41make87_messages_ros2/rolling/geometry_msgs/msg/pose_stamped.proto\x1a\x34make87_messages_ros2/rolling/nav_msgs/msg/path.proto\"\xba\x01\n\x0eGetPlanRequest\x12J\n\x05start\x18\x01 \x01(\x0b\x32;.make87_messages_ros2.rolling.geometry_msgs.msg.PoseStamped\x12I\n\x04goal\x18\x02 \x01(\x0b\x32;.make87_messages_ros2.rolling.geometry_msgs.msg.PoseStamped\x12\x11\n\ttolerance\x18\x03 \x01(\x02\"P\n\x0fGetPlanResponse\x12=\n\x04plan\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.rolling.nav_msgs.msg.Pathb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.nav_msgs.srv.get_plan_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETPLANREQUEST']._serialized_start=225
  _globals['_GETPLANREQUEST']._serialized_end=411
  _globals['_GETPLANRESPONSE']._serialized_start=413
  _globals['_GETPLANRESPONSE']._serialized_end=493
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import traffic_dependency_pb2 as _traffic_dependency_pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import trajectory_pb2 as _trajectory_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Route(_message.Message):
    __slots__ = ["header", "map", "trajectory", "checkpoints", "dependencies"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MAP_FIELD_NUMBER: _ClassVar[int]
    TRAJECTORY_FIELD_NUMBER: _ClassVar[int]
    CHECKPOINTS_FIELD_NUMBER: _ClassVar[int]
    DEPENDENCIES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    map: str
    trajectory: _trajectory_pb2.Trajectory
    checkpoints: _containers.RepeatedScalarFieldContainer[int]
    dependencies: _containers.RepeatedCompositeFieldContainer[_traffic_dependency_pb2.TrafficDependency]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., map: _Optional[str] = ..., trajectory: _Optional[_Union[_trajectory_pb2.Trajectory, _Mapping]] = ..., checkpoints: _Optional[_Iterable[int]] = ..., dependencies: _Optional[_Iterable[_Union[_traffic_dependency_pb2.TrafficDependency, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ConstraintEvalResult(_message.Message):
    __slots__ = ["result", "distance"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_FIELD_NUMBER: _ClassVar[int]
    result: bool
    distance: float
    def __init__(self, result: bool = ..., distance: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/geographic_msgs/msg/geographic_map_changes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geographic_msgs.msg import geographic_map_pb2 as make87__messages__ros2_dot_jazzy_dot_geographic__msgs_dot_msg_dot_geographic__map__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.unique_identifier_msgs.msg import uuid_pb2 as make87__messages__ros2_dot_jazzy_dot_unique__identifier__msgs_dot_msg_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/jazzy/geographic_msgs/msg/geographic_map_changes.proto\x12.make87_messages_ros2.jazzy.geographic_msgs.msg\x1a\x43make87_messages_ros2/jazzy/geographic_msgs/msg/geographic_map.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1a@make87_messages_ros2/jazzy/unique_identifier_msgs/msg/uuid.proto\"\xf3\x01\n\x14GeographicMapChanges\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12L\n\x05\x64iffs\x18\x02 \x01(\x0b\x32=.make87_messages_ros2.jazzy.geographic_msgs.msg.GeographicMap\x12L\n\x07\x64\x65letes\x18\x03 \x03(\x0b\x32;.make87_messages_ros2.jazzy.unique_identifier_msgs.msg.UUIDb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.geographic_msgs.msg.geographic_map_changes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GEOGRAPHICMAPCHANGES']._serialized_start=317
  _globals['_GEOGRAPHICMAPCHANGES']._serialized_end=560
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_reservation_msgs/msg/claim_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_reservation_msgs.msg import ticket_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__reservation__msgs_dot_msg_dot_ticket__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/rmf_reservation_msgs/msg/claim_request.proto\x12\x35make87_messages_ros2.rolling.rmf_reservation_msgs.msg\x1a\x42make87_messages_ros2/rolling/rmf_reservation_msgs/msg/ticket.proto\"r\n\x0c\x43laimRequest\x12M\n\x06ticket\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.rolling.rmf_reservation_msgs.msg.Ticket\x12\x13\n\x0bwait_points\x18\x02 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_reservation_msgs.msg.claim_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CLAIMREQUEST']._serialized_start=200
  _globals['_CLAIMREQUEST']._serialized_end=314
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/space.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose2_d_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose2__d__pb2
from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import shape_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_shape__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/rolling/rmf_traffic_msgs/msg/space.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\x1a<make87_messages_ros2/rolling/geometry_msgs/msg/pose2_d.proto\x1a=make87_messages_ros2/rolling/rmf_traffic_msgs/msg/shape.proto\"\x96\x01\n\x05Space\x12G\n\x05shape\x18\x01 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.Shape\x12\x44\n\x04pose\x18\x02 \x01(\x0b\x32\x36.make87_messages_ros2.rolling.geometry_msgs.msg.Pose2Db\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.space_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SPACE']._serialized_start=242
  _globals['_SPACE']._serialized_end=392
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_participant_patch.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_change_add_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_schedule__change__add__pb2
from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_change_delay_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_schedule__change__delay__pb2
from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_change_progress_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_schedule__change__progress__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_participant_patch.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\x1aKmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_change_add.proto\x1aMmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_change_delay.proto\x1aPmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_change_progress.proto\"\xed\x02\n\x18ScheduleParticipantPatch\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\x04\x12\x19\n\x11itinerary_version\x18\x02 \x01(\x04\x12\x10\n\x08\x65rasures\x18\x03 \x03(\x04\x12V\n\x06\x64\x65lays\x18\x04 \x03(\x0b\x32\x46.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.ScheduleChangeDelay\x12W\n\tadditions\x18\x05 \x01(\x0b\x32\x44.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.ScheduleChangeAdd\x12[\n\x08progress\x18\x06 \x01(\x0b\x32I.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.ScheduleChangeProgressb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.schedule_participant_patch_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCHEDULEPARTICIPANTPATCH']._serialized_start=376
  _globals['_SCHEDULEPARTICIPANTPATCH']._serialized_end=741
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mobileye_560_660_msgs/msg/obstacle_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/mobileye_560_660_msgs/msg/obstacle_data.proto\x12\x36make87_messages_ros2.rolling.mobileye_560_660_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xa3\x05\n\x0cObstacleData\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x13\n\x0bobstacle_id\x18\x02 \x01(\r\x12\x16\n\x0eobstacle_pos_x\x18\x03 \x01(\x01\x12\x16\n\x0eobstacle_pos_y\x18\x04 \x01(\x01\x12\x14\n\x0c\x62linker_info\x18\x05 \x01(\r\x12\x16\n\x0e\x63ut_in_and_out\x18\x06 \x01(\r\x12\x1a\n\x12obstacle_rel_vel_x\x18\x07 \x01(\x01\x12\x15\n\robstacle_type\x18\x08 \x01(\r\x12\x17\n\x0fobstacle_status\x18\t \x01(\r\x12\x1d\n\x15obstacle_brake_lights\x18\n \x01(\x08\x12\x16\n\x0eobstacle_valid\x18\x0b \x01(\r\x12\x17\n\x0fobstacle_length\x18\x0c \x01(\x02\x12\x16\n\x0eobstacle_width\x18\r \x01(\x02\x12\x14\n\x0cobstacle_age\x18\x0e \x01(\r\x12\x15\n\robstacle_lane\x18\x0f \x01(\r\x12\x11\n\tcipv_flag\x18\x10 \x01(\x08\x12\x13\n\x0bradar_pos_x\x18\x11 \x01(\x02\x12\x13\n\x0bradar_vel_x\x18\x12 \x01(\x02\x12\x1e\n\x16radar_match_confidence\x18\x13 \x01(\r\x12\x18\n\x10matched_radar_id\x18\x14 \x01(\r\x12\x1b\n\x13obstacle_angle_rate\x18\x15 \x01(\x02\x12\x1d\n\x15obstacle_scale_change\x18\x16 \x01(\x01\x12\x16\n\x0eobject_accel_x\x18\x17 \x01(\x02\x12\x19\n\x11obstacle_replaced\x18\x18 \x01(\x08\x12\x16\n\x0eobstacle_angle\x18\x19 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mobileye_560_660_msgs.msg.obstacle_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBSTACLEDATA']._serialized_start=191
  _globals['_OBSTACLEDATA']._serialized_end=866
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsrStatus9(_message.Message):
    __slots__ = ["header", "canmsg", "avg_pwr_cwblkg", "sideslip_angle", "serial_num_3rd_byte", "water_spray_target_id", "filtered_xohp_acc_cipv", "path_id_acc_2", "path_id_acc_3"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CANMSG_FIELD_NUMBER: _ClassVar[int]
    AVG_PWR_CWBLKG_FIELD_NUMBER: _ClassVar[int]
    SIDESLIP_ANGLE_FIELD_NUMBER: _ClassVar[int]
    SERIAL_NUM_3RD_BYTE_FIELD_NUMBER: _ClassVar[int]
    WATER_SPRAY_TARGET_ID_FIELD_NUMBER: _ClassVar[int]
    FILTERED_XOHP_ACC_CIPV_FIELD_NUMBER: _ClassVar[int]
    PATH_ID_ACC_2_FIELD_NUMBER: _ClassVar[int]
    PATH_ID_ACC_3_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    canmsg: str
    avg_pwr_cwblkg: int
    sideslip_angle: float
    serial_num_3rd_byte: int
    water_spray_target_id: int
    filtered_xohp_acc_cipv: float
    path_id_acc_2: int
    path_id_acc_3: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., canmsg: _Optional[str] = ..., avg_pwr_cwblkg: _Optional[int] = ..., sideslip_angle: _Optional[float] = ..., serial_num_3rd_byte: _Optional[int] = ..., water_spray_target_id: _Optional[int] = ..., filtered_xohp_acc_cipv: _Optional[float] = ..., path_id_acc_2: _Optional[int] = ..., path_id_acc_3: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VehicleControl(_message.Message):
    __slots__ = ["header", "engine", "gear", "steering", "throttle", "brake", "steering_position", "gb_position"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ENGINE_FIELD_NUMBER: _ClassVar[int]
    GEAR_FIELD_NUMBER: _ClassVar[int]
    STEERING_FIELD_NUMBER: _ClassVar[int]
    THROTTLE_FIELD_NUMBER: _ClassVar[int]
    BRAKE_FIELD_NUMBER: _ClassVar[int]
    STEERING_POSITION_FIELD_NUMBER: _ClassVar[int]
    GB_POSITION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    engine: int
    gear: int
    steering: float
    throttle: float
    brake: float
    steering_position: int
    gb_position: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., engine: _Optional[int] = ..., gear: _Optional[int] = ..., steering: _Optional[float] = ..., throttle: _Optional[float] = ..., brake: _Optional[float] = ..., steering_position: _Optional[int] = ..., gb_position: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/trajectory_msgs/msg/multi_dof_joint_trajectory_point.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import transform_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_transform__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import twist_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_twist__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUmake87_messages_ros2/jazzy/trajectory_msgs/msg/multi_dof_joint_trajectory_point.proto\x12.make87_messages_ros2.jazzy.trajectory_msgs.msg\x1a@make87_messages_ros2/jazzy/builtin_interfaces/msg/duration.proto\x1a<make87_messages_ros2/jazzy/geometry_msgs/msg/transform.proto\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/twist.proto\"\xd6\x02\n\x1cMultiDOFJointTrajectoryPoint\x12K\n\ntransforms\x18\x01 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.geometry_msgs.msg.Transform\x12G\n\nvelocities\x18\x02 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Twist\x12J\n\raccelerations\x18\x03 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Twist\x12T\n\x0ftime_from_start\x18\x04 \x01(\x0b\x32;.make87_messages_ros2.jazzy.builtin_interfaces.msg.Durationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.trajectory_msgs.msg.multi_dof_joint_trajectory_point_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MULTIDOFJOINTTRAJECTORYPOINT']._serialized_start=324
  _globals['_MULTIDOFJOINTTRAJECTORYPOINT']._serialized_end=666
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ibeo_msgs/msg/scan_data2202.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import ibeo_data_header_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_ibeo__data__header__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import scan_point2202_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_scan__point2202__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/rolling/ibeo_msgs/msg/scan_data2202.proto\x12*make87_messages_ros2.rolling.ibeo_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a\x41make87_messages_ros2/rolling/ibeo_msgs/msg/ibeo_data_header.proto\x1a?make87_messages_ros2/rolling/ibeo_msgs/msg/scan_point2202.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xee\x06\n\x0cScanData2202\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12O\n\x0bibeo_header\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.rolling.ibeo_msgs.msg.IbeoDataHeader\x12\x13\n\x0bscan_number\x18\x03 \x01(\r\x12\x16\n\x0escanner_status\x18\x04 \x01(\r\x12\x19\n\x11sync_phase_offset\x18\x05 \x01(\r\x12R\n\x0fscan_start_time\x18\x06 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12P\n\rscan_end_time\x18\x07 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12 \n\x18\x61ngle_ticks_per_rotation\x18\x08 \x01(\r\x12\x19\n\x11start_angle_ticks\x18\t \x01(\x05\x12\x17\n\x0f\x65nd_angle_ticks\x18\n \x01(\x05\x12\x19\n\x11scan_points_count\x18\x0b \x01(\r\x12 \n\x18mounting_yaw_angle_ticks\x18\x0c \x01(\x05\x12\"\n\x1amounting_pitch_angle_ticks\x18\r \x01(\x05\x12!\n\x19mounting_roll_angle_ticks\x18\x0e \x01(\x05\x12\x1b\n\x13mounting_position_x\x18\x0f \x01(\x05\x12\x1b\n\x13mounting_position_y\x18\x10 \x01(\x05\x12\x1b\n\x13mounting_position_z\x18\x11 \x01(\x05\x12\x16\n\x0eground_labeled\x18\x12 \x01(\x08\x12\x14\n\x0c\x64irt_labeled\x18\x13 \x01(\x08\x12\x14\n\x0crain_labeled\x18\x14 \x01(\x08\x12\x13\n\x0bmirror_side\x18\x15 \x01(\r\x12R\n\x0fscan_point_list\x18\x16 \x03(\x0b\x32\x39.make87_messages_ros2.rolling.ibeo_msgs.msg.ScanPoint2202b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ibeo_msgs.msg.scan_data2202_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCANDATA2202']._serialized_start=363
  _globals['_SCANDATA2202']._serialized_end=1241
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/sick_safetyscanners2_interfaces/msg/scan_point.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/humble/sick_safetyscanners2_interfaces/msg/scan_point.proto\x12?make87_messages_ros2.humble.sick_safetyscanners2_interfaces.msg\x1a!make87_messages/core/header.proto\"\xe9\x01\n\tScanPoint\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05\x61ngle\x18\x02 \x01(\x02\x12\x10\n\x08\x64istance\x18\x03 \x01(\r\x12\x14\n\x0creflectivity\x18\x04 \x01(\r\x12\r\n\x05valid\x18\x05 \x01(\x08\x12\x10\n\x08infinite\x18\x06 \x01(\x08\x12\r\n\x05glare\x18\x07 \x01(\x08\x12\x11\n\treflector\x18\x08 \x01(\x08\x12\x15\n\rcontamination\x18\t \x01(\x08\x12\x1d\n\x15\x63ontamination_warning\x18\n \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.sick_safetyscanners2_interfaces.msg.scan_point_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCANPOINT']._serialized_start=185
  _globals['_SCANPOINT']._serialized_end=418
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/py_trees_ros_interfaces/srv/introspect_publishers.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.py_trees_ros_interfaces.msg import publisher_details_pb2 as make87__messages__ros2_dot_humble_dot_py__trees__ros__interfaces_dot_msg_dot_publisher__details__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/humble/py_trees_ros_interfaces/srv/introspect_publishers.proto\x12\x37make87_messages_ros2.humble.py_trees_ros_interfaces.srv\x1a!make87_messages/core/header.proto\x1aOmake87_messages_ros2/humble/py_trees_ros_interfaces/msg/publisher_details.proto\"K\n\x1bIntrospectPublishersRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\"\xb2\x01\n\x1cIntrospectPublishersResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x64\n\x11publisher_details\x18\x02 \x03(\x0b\x32I.make87_messages_ros2.humble.py_trees_ros_interfaces.msg.PublisherDetailsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.py_trees_ros_interfaces.srv.introspect_publishers_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_INTROSPECTPUBLISHERSREQUEST']._serialized_start=260
  _globals['_INTROSPECTPUBLISHERSREQUEST']._serialized_end=335
  _globals['_INTROSPECTPUBLISHERSRESPONSE']._serialized_start=338
  _globals['_INTROSPECTPUBLISHERSRESPONSE']._serialized_end=516
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HilSensor(_message.Message):
    __slots__ = ["header", "acc", "gyro", "mag", "abs_pressure", "diff_pressure", "pressure_alt", "temperature", "fields_updated"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ACC_FIELD_NUMBER: _ClassVar[int]
    GYRO_FIELD_NUMBER: _ClassVar[int]
    MAG_FIELD_NUMBER: _ClassVar[int]
    ABS_PRESSURE_FIELD_NUMBER: _ClassVar[int]
    DIFF_PRESSURE_FIELD_NUMBER: _ClassVar[int]
    PRESSURE_ALT_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    FIELDS_UPDATED_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    acc: _vector3_pb2.Vector3
    gyro: _vector3_pb2.Vector3
    mag: _vector3_pb2.Vector3
    abs_pressure: float
    diff_pressure: float
    pressure_alt: float
    temperature: float
    fields_updated: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., acc: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., gyro: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., mag: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., abs_pressure: _Optional[float] = ..., diff_pressure: _Optional[float] = ..., pressure_alt: _Optional[float] = ..., temperature: _Optional[float] = ..., fields_updated: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.geographic_msgs.msg import geo_point_pb2 as _geo_point_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as _point_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ToLLRequest(_message.Message):
    __slots__ = ["map_point"]
    MAP_POINT_FIELD_NUMBER: _ClassVar[int]
    map_point: _point_pb2.Point
    def __init__(self, map_point: _Optional[_Union[_point_pb2.Point, _Mapping]] = ...) -> None: ...

class ToLLResponse(_message.Message):
    __slots__ = ["ll_point"]
    LL_POINT_FIELD_NUMBER: _ClassVar[int]
    ll_point: _geo_point_pb2.GeoPoint
    def __init__(self, ll_point: _Optional[_Union[_geo_point_pb2.GeoPoint, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from make87_messages_ros2.humble.ublox_ubx_msgs.msg import orb_sv_info_pb2 as _orb_sv_info_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXNavOrb(_message.Message):
    __slots__ = ["header", "ros2_header", "itow", "version", "num_sv", "reserved_0", "sv_info"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    ITOW_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    NUM_SV_FIELD_NUMBER: _ClassVar[int]
    RESERVED_0_FIELD_NUMBER: _ClassVar[int]
    SV_INFO_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    itow: int
    version: int
    num_sv: int
    reserved_0: _containers.RepeatedScalarFieldContainer[int]
    sv_info: _containers.RepeatedCompositeFieldContainer[_orb_sv_info_pb2.OrbSVInfo]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., itow: _Optional[int] = ..., version: _Optional[int] = ..., num_sv: _Optional[int] = ..., reserved_0: _Optional[_Iterable[int]] = ..., sv_info: _Optional[_Iterable[_Union[_orb_sv_info_pb2.OrbSVInfo, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.micro_ros_diagnostic_msgs.msg import micro_ros_diagnostic_key_value_pb2 as _micro_ros_diagnostic_key_value_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MicroROSDiagnosticStatus(_message.Message):
    __slots__ = ["level", "updater_id", "hardware_id", "number_of_values", "values"]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    UPDATER_ID_FIELD_NUMBER: _ClassVar[int]
    HARDWARE_ID_FIELD_NUMBER: _ClassVar[int]
    NUMBER_OF_VALUES_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    level: int
    updater_id: int
    hardware_id: int
    number_of_values: int
    values: _containers.RepeatedCompositeFieldContainer[_micro_ros_diagnostic_key_value_pb2.MicroROSDiagnosticKeyValue]
    def __init__(self, level: _Optional[int] = ..., updater_id: _Optional[int] = ..., hardware_id: _Optional[int] = ..., number_of_values: _Optional[int] = ..., values: _Optional[_Iterable[_Union[_micro_ros_diagnostic_key_value_pb2.MicroROSDiagnosticKeyValue, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsrStatus4(_message.Message):
    __slots__ = ["header", "canmsg", "truck_target_det", "lr_only_grating_lobe_det", "sidelobe_blockage", "partial_blockage", "mr_lr_mode", "rolling_count_3", "path_id_acc", "path_id_cmbb_move", "path_id_cmbb_stat", "path_id_fcw_move", "path_id_fcw_stat", "auto_align_angle", "path_id_acc_stat"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CANMSG_FIELD_NUMBER: _ClassVar[int]
    TRUCK_TARGET_DET_FIELD_NUMBER: _ClassVar[int]
    LR_ONLY_GRATING_LOBE_DET_FIELD_NUMBER: _ClassVar[int]
    SIDELOBE_BLOCKAGE_FIELD_NUMBER: _ClassVar[int]
    PARTIAL_BLOCKAGE_FIELD_NUMBER: _ClassVar[int]
    MR_LR_MODE_FIELD_NUMBER: _ClassVar[int]
    ROLLING_COUNT_3_FIELD_NUMBER: _ClassVar[int]
    PATH_ID_ACC_FIELD_NUMBER: _ClassVar[int]
    PATH_ID_CMBB_MOVE_FIELD_NUMBER: _ClassVar[int]
    PATH_ID_CMBB_STAT_FIELD_NUMBER: _ClassVar[int]
    PATH_ID_FCW_MOVE_FIELD_NUMBER: _ClassVar[int]
    PATH_ID_FCW_STAT_FIELD_NUMBER: _ClassVar[int]
    AUTO_ALIGN_ANGLE_FIELD_NUMBER: _ClassVar[int]
    PATH_ID_ACC_STAT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    canmsg: str
    truck_target_det: bool
    lr_only_grating_lobe_det: bool
    sidelobe_blockage: bool
    partial_blockage: bool
    mr_lr_mode: int
    rolling_count_3: int
    path_id_acc: int
    path_id_cmbb_move: int
    path_id_cmbb_stat: int
    path_id_fcw_move: int
    path_id_fcw_stat: int
    auto_align_angle: float
    path_id_acc_stat: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., canmsg: _Optional[str] = ..., truck_target_det: bool = ..., lr_only_grating_lobe_det: bool = ..., sidelobe_blockage: bool = ..., partial_blockage: bool = ..., mr_lr_mode: _Optional[int] = ..., rolling_count_3: _Optional[int] = ..., path_id_acc: _Optional[int] = ..., path_id_cmbb_move: _Optional[int] = ..., path_id_cmbb_stat: _Optional[int] = ..., path_id_fcw_move: _Optional[int] = ..., path_id_fcw_stat: _Optional[int] = ..., auto_align_angle: _Optional[float] = ..., path_id_acc_stat: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/plansys2_msgs/srv/add_problem.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/jazzy/plansys2_msgs/srv/add_problem.proto\x12,make87_messages_ros2.jazzy.plansys2_msgs.srv\"$\n\x11\x41\x64\x64ProblemRequest\x12\x0f\n\x07problem\x18\x01 \x01(\t\"9\n\x12\x41\x64\x64ProblemResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x12\n\nerror_info\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.plansys2_msgs.srv.add_problem_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ADDPROBLEMREQUEST']._serialized_start=112
  _globals['_ADDPROBLEMREQUEST']._serialized_end=148
  _globals['_ADDPROBLEMRESPONSE']._serialized_start=150
  _globals['_ADDPROBLEMRESPONSE']._serialized_end=207
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NovatelExtendedSolutionStatus(_message.Message):
    __slots__ = ["header", "original_mask", "advance_rtk_verified", "psuedorange_iono_correction"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ORIGINAL_MASK_FIELD_NUMBER: _ClassVar[int]
    ADVANCE_RTK_VERIFIED_FIELD_NUMBER: _ClassVar[int]
    PSUEDORANGE_IONO_CORRECTION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    original_mask: int
    advance_rtk_verified: bool
    psuedorange_iono_correction: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., original_mask: _Optional[int] = ..., advance_rtk_verified: bool = ..., psuedorange_iono_correction: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CommandTOLLocalRequest(_message.Message):
    __slots__ = ["header", "min_pitch", "offset", "rate", "yaw", "position"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MIN_PITCH_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    RATE_FIELD_NUMBER: _ClassVar[int]
    YAW_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    min_pitch: float
    offset: float
    rate: float
    yaw: float
    position: _vector3_pb2.Vector3
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., min_pitch: _Optional[float] = ..., offset: _Optional[float] = ..., rate: _Optional[float] = ..., yaw: _Optional[float] = ..., position: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ...) -> None: ...

class CommandTOLLocalResponse(_message.Message):
    __slots__ = ["header", "success", "result"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    result: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., result: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Info(_message.Message):
    __slots__ = ["header", "id", "serial_port", "max_repeats", "get_positions", "get_currents", "get_distinct_packages", "set_commands", "set_commands_async", "position_limits", "encoder_resolutions"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    SERIAL_PORT_FIELD_NUMBER: _ClassVar[int]
    MAX_REPEATS_FIELD_NUMBER: _ClassVar[int]
    GET_POSITIONS_FIELD_NUMBER: _ClassVar[int]
    GET_CURRENTS_FIELD_NUMBER: _ClassVar[int]
    GET_DISTINCT_PACKAGES_FIELD_NUMBER: _ClassVar[int]
    SET_COMMANDS_FIELD_NUMBER: _ClassVar[int]
    SET_COMMANDS_ASYNC_FIELD_NUMBER: _ClassVar[int]
    POSITION_LIMITS_FIELD_NUMBER: _ClassVar[int]
    ENCODER_RESOLUTIONS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    id: int
    serial_port: str
    max_repeats: int
    get_positions: bool
    get_currents: bool
    get_distinct_packages: bool
    set_commands: bool
    set_commands_async: bool
    position_limits: _containers.RepeatedScalarFieldContainer[int]
    encoder_resolutions: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., id: _Optional[int] = ..., serial_port: _Optional[str] = ..., max_repeats: _Optional[int] = ..., get_positions: bool = ..., get_currents: bool = ..., get_distinct_packages: bool = ..., set_commands: bool = ..., set_commands_async: bool = ..., position_limits: _Optional[_Iterable[int]] = ..., encoder_resolutions: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/bosch_locator_bridge/srv/client_expand_map_enable.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/humble/bosch_locator_bridge/srv/client_expand_map_enable.proto\x12\x34make87_messages_ros2.humble.bosch_locator_bridge.srv\x1a!make87_messages/core/header.proto\"d\n\x1c\x43lientExpandMapEnableRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x16\n\x0eprior_map_name\x18\x02 \x01(\t\"M\n\x1d\x43lientExpandMapEnableResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Headerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.bosch_locator_bridge.srv.client_expand_map_enable_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CLIENTEXPANDMAPENABLEREQUEST']._serialized_start=176
  _globals['_CLIENTEXPANDMAPENABLEREQUEST']._serialized_end=276
  _globals['_CLIENTEXPANDMAPENABLERESPONSE']._serialized_start=278
  _globals['_CLIENTEXPANDMAPENABLERESPONSE']._serialized_end=355
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ouster_msgs/msg/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/humble/ouster_msgs/msg/metadata.proto\x12+make87_messages_ros2.humble.ouster_msgs.msg\x1a!make87_messages/core/header.proto\"\xc4\x02\n\x08Metadata\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x12\n\nlidar_mode\x18\x03 \x01(\t\x12\x16\n\x0etimestamp_mode\x18\x04 \x01(\t\x12\x1b\n\x13\x62\x65\x61m_azimuth_angles\x18\x05 \x03(\x01\x12\x1c\n\x14\x62\x65\x61m_altitude_angles\x18\x06 \x03(\x01\x12\x1f\n\x17imu_to_sensor_transform\x18\x07 \x03(\x01\x12!\n\x19lidar_to_sensor_transform\x18\x08 \x03(\x01\x12\x11\n\tserial_no\x18\t \x01(\t\x12\x14\n\x0c\x66irmware_rev\x18\n \x01(\t\x12\x10\n\x08imu_port\x18\x0b \x01(\x05\x12\x12\n\nlidar_port\x18\x0c \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ouster_msgs.msg.metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_METADATA']._serialized_start=143
  _globals['_METADATA']._serialized_end=467
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/place_location.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import gripper_translation_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_gripper__translation__pb2
from make87_messages_ros2.jazzy.trajectory_msgs.msg import joint_trajectory_pb2 as make87__messages__ros2_dot_jazzy_dot_trajectory__msgs_dot_msg_dot_joint__trajectory__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/moveit_msgs/msg/place_location.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1a?make87_messages_ros2/jazzy/geometry_msgs/msg/pose_stamped.proto\x1a\x44make87_messages_ros2/jazzy/moveit_msgs/msg/gripper_translation.proto\x1a\x45make87_messages_ros2/jazzy/trajectory_msgs/msg/joint_trajectory.proto\"\xaf\x03\n\rPlaceLocation\x12\n\n\x02id\x18\x01 \x01(\t\x12[\n\x12post_place_posture\x18\x02 \x01(\x0b\x32?.make87_messages_ros2.jazzy.trajectory_msgs.msg.JointTrajectory\x12M\n\nplace_pose\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.geometry_msgs.msg.PoseStamped\x12\x0f\n\x07quality\x18\x04 \x01(\x01\x12Z\n\x12pre_place_approach\x18\x05 \x01(\x0b\x32>.make87_messages_ros2.jazzy.moveit_msgs.msg.GripperTranslation\x12Z\n\x12post_place_retreat\x18\x06 \x01(\x0b\x32>.make87_messages_ros2.jazzy.moveit_msgs.msg.GripperTranslation\x12\x1d\n\x15\x61llowed_touch_objects\x18\x07 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.place_location_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PLACELOCATION']._serialized_start=318
  _globals['_PLACELOCATION']._serialized_end=749
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.game_controller_spl_interfaces.msg import team_info14_pb2 as _team_info14_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RCGCD14(_message.Message):
    __slots__ = ["packet_number", "players_per_team", "competition_phase", "competition_type", "game_phase", "state", "set_play", "first_half", "kicking_team", "secs_remaining", "secondary_time", "teams"]
    PACKET_NUMBER_FIELD_NUMBER: _ClassVar[int]
    PLAYERS_PER_TEAM_FIELD_NUMBER: _ClassVar[int]
    COMPETITION_PHASE_FIELD_NUMBER: _ClassVar[int]
    COMPETITION_TYPE_FIELD_NUMBER: _ClassVar[int]
    GAME_PHASE_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    SET_PLAY_FIELD_NUMBER: _ClassVar[int]
    FIRST_HALF_FIELD_NUMBER: _ClassVar[int]
    KICKING_TEAM_FIELD_NUMBER: _ClassVar[int]
    SECS_REMAINING_FIELD_NUMBER: _ClassVar[int]
    SECONDARY_TIME_FIELD_NUMBER: _ClassVar[int]
    TEAMS_FIELD_NUMBER: _ClassVar[int]
    packet_number: int
    players_per_team: int
    competition_phase: int
    competition_type: int
    game_phase: int
    state: int
    set_play: int
    first_half: int
    kicking_team: int
    secs_remaining: int
    secondary_time: int
    teams: _containers.RepeatedCompositeFieldContainer[_team_info14_pb2.TeamInfo14]
    def __init__(self, packet_number: _Optional[int] = ..., players_per_team: _Optional[int] = ..., competition_phase: _Optional[int] = ..., competition_type: _Optional[int] = ..., game_phase: _Optional[int] = ..., state: _Optional[int] = ..., set_play: _Optional[int] = ..., first_half: _Optional[int] = ..., kicking_team: _Optional[int] = ..., secs_remaining: _Optional[int] = ..., secondary_time: _Optional[int] = ..., teams: _Optional[_Iterable[_Union[_team_info14_pb2.TeamInfo14, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import ibeo_data_header_pb2 as _ibeo_data_header_pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import mounting_position_f_pb2 as _mounting_position_f_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CameraImage(_message.Message):
    __slots__ = ["header", "ibeo_header", "image_format", "us_since_power_on", "timestamp", "device_id", "mounting_position", "horizontal_opening_angle", "vertical_opening_angle", "image_width", "image_height", "compressed_size", "image_buffer"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    IBEO_HEADER_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FORMAT_FIELD_NUMBER: _ClassVar[int]
    US_SINCE_POWER_ON_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    MOUNTING_POSITION_FIELD_NUMBER: _ClassVar[int]
    HORIZONTAL_OPENING_ANGLE_FIELD_NUMBER: _ClassVar[int]
    VERTICAL_OPENING_ANGLE_FIELD_NUMBER: _ClassVar[int]
    IMAGE_WIDTH_FIELD_NUMBER: _ClassVar[int]
    IMAGE_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    COMPRESSED_SIZE_FIELD_NUMBER: _ClassVar[int]
    IMAGE_BUFFER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ibeo_header: _ibeo_data_header_pb2.IbeoDataHeader
    image_format: int
    us_since_power_on: int
    timestamp: _time_pb2.Time
    device_id: int
    mounting_position: _mounting_position_f_pb2.MountingPositionF
    horizontal_opening_angle: float
    vertical_opening_angle: float
    image_width: int
    image_height: int
    compressed_size: int
    image_buffer: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ibeo_header: _Optional[_Union[_ibeo_data_header_pb2.IbeoDataHeader, _Mapping]] = ..., image_format: _Optional[int] = ..., us_since_power_on: _Optional[int] = ..., timestamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., device_id: _Optional[int] = ..., mounting_position: _Optional[_Union[_mounting_position_f_pb2.MountingPositionF, _Mapping]] = ..., horizontal_opening_angle: _Optional[float] = ..., vertical_opening_angle: _Optional[float] = ..., image_width: _Optional[int] = ..., image_height: _Optional[int] = ..., compressed_size: _Optional[int] = ..., image_buffer: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/septentrio_gnss_driver/msg/rf_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.septentrio_gnss_driver.msg import block_header_pb2 as make87__messages__ros2_dot_rolling_dot_septentrio__gnss__driver_dot_msg_dot_block__header__pb2
from make87_messages_ros2.rolling.septentrio_gnss_driver.msg import rf_band_pb2 as make87__messages__ros2_dot_rolling_dot_septentrio__gnss__driver_dot_msg_dot_rf__band__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/septentrio_gnss_driver/msg/rf_status.proto\x12\x37make87_messages_ros2.rolling.septentrio_gnss_driver.msg\x1aJmake87_messages_ros2/rolling/septentrio_gnss_driver/msg/block_header.proto\x1a\x45make87_messages_ros2/rolling/septentrio_gnss_driver/msg/rf_band.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xa7\x02\n\x08RFStatus\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12Z\n\x0c\x62lock_header\x18\x02 \x01(\x0b\x32\x44.make87_messages_ros2.rolling.septentrio_gnss_driver.msg.BlockHeader\x12\t\n\x01n\x18\x03 \x01(\r\x12\x11\n\tsb_length\x18\x04 \x01(\r\x12\r\n\x05\x66lags\x18\x05 \x01(\r\x12O\n\x06rfband\x18\x06 \x03(\x0b\x32?.make87_messages_ros2.rolling.septentrio_gnss_driver.msg.RFBandb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.septentrio_gnss_driver.msg.rf_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RFSTATUS']._serialized_start=336
  _globals['_RFSTATUS']._serialized_end=631
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Tow(_message.Message):
    __slots__ = ["task_id", "object_type", "is_object_id_known", "object_id", "pickup_place_name", "is_dropoff_place_known", "dropoff_place_name"]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_TYPE_FIELD_NUMBER: _ClassVar[int]
    IS_OBJECT_ID_KNOWN_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PICKUP_PLACE_NAME_FIELD_NUMBER: _ClassVar[int]
    IS_DROPOFF_PLACE_KNOWN_FIELD_NUMBER: _ClassVar[int]
    DROPOFF_PLACE_NAME_FIELD_NUMBER: _ClassVar[int]
    task_id: str
    object_type: str
    is_object_id_known: bool
    object_id: str
    pickup_place_name: str
    is_dropoff_place_known: bool
    dropoff_place_name: str
    def __init__(self, task_id: _Optional[str] = ..., object_type: _Optional[str] = ..., is_object_id_known: bool = ..., object_id: _Optional[str] = ..., pickup_place_name: _Optional[str] = ..., is_dropoff_place_known: bool = ..., dropoff_place_name: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_task_msgs/msg/tow.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6make87_messages_ros2/jazzy/rmf_task_msgs/msg/tow.proto\x12,make87_messages_ros2.jazzy.rmf_task_msgs.msg\"\xb1\x01\n\x03Tow\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x13\n\x0bobject_type\x18\x02 \x01(\t\x12\x1a\n\x12is_object_id_known\x18\x03 \x01(\x08\x12\x11\n\tobject_id\x18\x04 \x01(\t\x12\x19\n\x11pickup_place_name\x18\x05 \x01(\t\x12\x1e\n\x16is_dropoff_place_known\x18\x06 \x01(\x08\x12\x1a\n\x12\x64ropoff_place_name\x18\x07 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_task_msgs.msg.tow_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TOW']._serialized_start=105
  _globals['_TOW']._serialized_end=282
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_fleet_msgs/msg/closed_lanes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/rmf_fleet_msgs/msg/closed_lanes.proto\x12-make87_messages_ros2.jazzy.rmf_fleet_msgs.msg\"7\n\x0b\x43losedLanes\x12\x12\n\nfleet_name\x18\x01 \x01(\t\x12\x14\n\x0c\x63losed_lanes\x18\x02 \x03(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_fleet_msgs.msg.closed_lanes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CLOSEDLANES']._serialized_start=115
  _globals['_CLOSEDLANES']._serialized_end=170
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/geographic_msgs/srv/get_geographic_map.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geographic_msgs.msg import bounding_box_pb2 as make87__messages__ros2_dot_rolling_dot_geographic__msgs_dot_msg_dot_bounding__box__pb2
from make87_messages_ros2.rolling.geographic_msgs.msg import geographic_map_pb2 as make87__messages__ros2_dot_rolling_dot_geographic__msgs_dot_msg_dot_geographic__map__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/geographic_msgs/srv/get_geographic_map.proto\x12\x30make87_messages_ros2.rolling.geographic_msgs.srv\x1a\x43make87_messages_ros2/rolling/geographic_msgs/msg/bounding_box.proto\x1a\x45make87_messages_ros2/rolling/geographic_msgs/msg/geographic_map.proto\"u\n\x17GetGeographicMapRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\x12M\n\x06\x62ounds\x18\x02 \x01(\x0b\x32=.make87_messages_ros2.rolling.geographic_msgs.msg.BoundingBox\"\x89\x01\n\x18GetGeographicMapResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06status\x18\x02 \x01(\t\x12L\n\x03map\x18\x03 \x01(\x0b\x32?.make87_messages_ros2.rolling.geographic_msgs.msg.GeographicMapb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.geographic_msgs.srv.get_geographic_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETGEOGRAPHICMAPREQUEST']._serialized_start=267
  _globals['_GETGEOGRAPHICMAPREQUEST']._serialized_end=384
  _globals['_GETGEOGRAPHICMAPRESPONSE']._serialized_start=387
  _globals['_GETGEOGRAPHICMAPRESPONSE']._serialized_end=524
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/nav2_msgs/srv/get_costmap.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.nav2_msgs.msg import costmap_pb2 as make87__messages__ros2_dot_jazzy_dot_nav2__msgs_dot_msg_dot_costmap__pb2
from make87_messages_ros2.jazzy.nav2_msgs.msg import costmap_meta_data_pb2 as make87__messages__ros2_dot_jazzy_dot_nav2__msgs_dot_msg_dot_costmap__meta__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/nav2_msgs/srv/get_costmap.proto\x12(make87_messages_ros2.jazzy.nav2_msgs.srv\x1a\x36make87_messages_ros2/jazzy/nav2_msgs/msg/costmap.proto\x1a@make87_messages_ros2/jazzy/nav2_msgs/msg/costmap_meta_data.proto\"]\n\x11GetCostmapRequest\x12H\n\x05specs\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.nav2_msgs.msg.CostmapMetaData\"T\n\x12GetCostmapResponse\x12>\n\x03map\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.jazzy.nav2_msgs.msg.Costmapb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.nav2_msgs.srv.get_costmap_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETCOSTMAPREQUEST']._serialized_start=226
  _globals['_GETCOSTMAPREQUEST']._serialized_end=319
  _globals['_GETCOSTMAPRESPONSE']._serialized_start=321
  _globals['_GETCOSTMAPRESPONSE']._serialized_end=405
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class UserLed(_message.Message):
    __slots__ = ["led", "color", "blink_period", "duty_cycle"]
    LED_FIELD_NUMBER: _ClassVar[int]
    COLOR_FIELD_NUMBER: _ClassVar[int]
    BLINK_PERIOD_FIELD_NUMBER: _ClassVar[int]
    DUTY_CYCLE_FIELD_NUMBER: _ClassVar[int]
    led: int
    color: int
    blink_period: int
    duty_cycle: float
    def __init__(self, led: _Optional[int] = ..., color: _Optional[int] = ..., blink_period: _Optional[int] = ..., duty_cycle: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MrrControlMsgFR(_message.Message):
    __slots__ = ["header", "can_sensitivity_profile_select", "can_stop_frequency_frml", "can_stop_frequency_frll", "can_prp_factor_frml", "can_prp_factor_frll", "can_desired_sweep_bw_frml", "can_desired_sweep_bw_frll"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAN_SENSITIVITY_PROFILE_SELECT_FIELD_NUMBER: _ClassVar[int]
    CAN_STOP_FREQUENCY_FRML_FIELD_NUMBER: _ClassVar[int]
    CAN_STOP_FREQUENCY_FRLL_FIELD_NUMBER: _ClassVar[int]
    CAN_PRP_FACTOR_FRML_FIELD_NUMBER: _ClassVar[int]
    CAN_PRP_FACTOR_FRLL_FIELD_NUMBER: _ClassVar[int]
    CAN_DESIRED_SWEEP_BW_FRML_FIELD_NUMBER: _ClassVar[int]
    CAN_DESIRED_SWEEP_BW_FRLL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    can_sensitivity_profile_select: int
    can_stop_frequency_frml: int
    can_stop_frequency_frll: int
    can_prp_factor_frml: float
    can_prp_factor_frll: float
    can_desired_sweep_bw_frml: int
    can_desired_sweep_bw_frll: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., can_sensitivity_profile_select: _Optional[int] = ..., can_stop_frequency_frml: _Optional[int] = ..., can_stop_frequency_frll: _Optional[int] = ..., can_prp_factor_frml: _Optional[float] = ..., can_prp_factor_frll: _Optional[float] = ..., can_desired_sweep_bw_frml: _Optional[int] = ..., can_desired_sweep_bw_frll: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.geographic_msgs.msg import geo_point_pb2 as _geo_point_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BoundingBox(_message.Message):
    __slots__ = ["min_pt", "max_pt"]
    MIN_PT_FIELD_NUMBER: _ClassVar[int]
    MAX_PT_FIELD_NUMBER: _ClassVar[int]
    min_pt: _geo_point_pb2.GeoPoint
    max_pt: _geo_point_pb2.GeoPoint
    def __init__(self, min_pt: _Optional[_Union[_geo_point_pb2.GeoPoint, _Mapping]] = ..., max_pt: _Optional[_Union[_geo_point_pb2.GeoPoint, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import bounding_volume_pb2 as _bounding_volume_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PositionConstraint(_message.Message):
    __slots__ = ["header", "link_name", "target_point_offset", "constraint_region", "weight"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LINK_NAME_FIELD_NUMBER: _ClassVar[int]
    TARGET_POINT_OFFSET_FIELD_NUMBER: _ClassVar[int]
    CONSTRAINT_REGION_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    link_name: str
    target_point_offset: _vector3_pb2.Vector3
    constraint_region: _bounding_volume_pb2.BoundingVolume
    weight: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., link_name: _Optional[str] = ..., target_point_offset: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., constraint_region: _Optional[_Union[_bounding_volume_pb2.BoundingVolume, _Mapping]] = ..., weight: _Optional[float] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class UdpSendRequest(_message.Message):
    __slots__ = ["local_address", "local_port", "remote_address", "remote_port", "data"]
    LOCAL_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    LOCAL_PORT_FIELD_NUMBER: _ClassVar[int]
    REMOTE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    REMOTE_PORT_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    local_address: str
    local_port: int
    remote_address: str
    remote_port: int
    data: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, local_address: _Optional[str] = ..., local_port: _Optional[int] = ..., remote_address: _Optional[str] = ..., remote_port: _Optional[int] = ..., data: _Optional[_Iterable[int]] = ...) -> None: ...

class UdpSendResponse(_message.Message):
    __slots__ = ["sent"]
    SENT_FIELD_NUMBER: _ClassVar[int]
    sent: bool
    def __init__(self, sent: bool = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class NavSATSV(_message.Message):
    __slots__ = ["gnss_id", "sv_id", "cno", "elev", "azim", "pr_res", "flags"]
    GNSS_ID_FIELD_NUMBER: _ClassVar[int]
    SV_ID_FIELD_NUMBER: _ClassVar[int]
    CNO_FIELD_NUMBER: _ClassVar[int]
    ELEV_FIELD_NUMBER: _ClassVar[int]
    AZIM_FIELD_NUMBER: _ClassVar[int]
    PR_RES_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    gnss_id: int
    sv_id: int
    cno: int
    elev: int
    azim: int
    pr_res: int
    flags: int
    def __init__(self, gnss_id: _Optional[int] = ..., sv_id: _Optional[int] = ..., cno: _Optional[int] = ..., elev: _Optional[int] = ..., azim: _Optional[int] = ..., pr_res: _Optional[int] = ..., flags: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.rc_common_msgs.msg import return_code_pb2 as _return_code_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeleteRegionsOfInterest3DRequest(_message.Message):
    __slots__ = ["header", "region_of_interest_ids"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    REGION_OF_INTEREST_IDS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    region_of_interest_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., region_of_interest_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class DeleteRegionsOfInterest3DResponse(_message.Message):
    __slots__ = ["header", "return_code"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    RETURN_CODE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    return_code: _return_code_pb2.ReturnCode
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., return_code: _Optional[_Union[_return_code_pb2.ReturnCode, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.depthai_ros_msgs.msg import tracked_feature_pb2 as _tracked_feature_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrackedFeatures(_message.Message):
    __slots__ = ["header", "features"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    features: _containers.RepeatedCompositeFieldContainer[_tracked_feature_pb2.TrackedFeature]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., features: _Optional[_Iterable[_Union[_tracked_feature_pb2.TrackedFeature, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GameState(_message.Message):
    __slots__ = ["time", "playmode", "score_left", "score_right"]
    TIME_FIELD_NUMBER: _ClassVar[int]
    PLAYMODE_FIELD_NUMBER: _ClassVar[int]
    SCORE_LEFT_FIELD_NUMBER: _ClassVar[int]
    SCORE_RIGHT_FIELD_NUMBER: _ClassVar[int]
    time: float
    playmode: str
    score_left: int
    score_right: int
    def __init__(self, time: _Optional[float] = ..., playmode: _Optional[str] = ..., score_left: _Optional[int] = ..., score_right: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_reservation_msgs/msg/flexible_time_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_reservation_msgs.msg import flexible_time_reservation_alt_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__reservation__msgs_dot_msg_dot_flexible__time__reservation__alt__pb2
from make87_messages_ros2.rolling.rmf_reservation_msgs.msg import request_header_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__reservation__msgs_dot_msg_dot_request__header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/rolling/rmf_reservation_msgs/msg/flexible_time_request.proto\x12\x35make87_messages_ros2.rolling.rmf_reservation_msgs.msg\x1aYmake87_messages_ros2/rolling/rmf_reservation_msgs/msg/flexible_time_reservation_alt.proto\x1aJmake87_messages_ros2/rolling/rmf_reservation_msgs/msg/request_header.proto\"\xd4\x01\n\x13\x46lexibleTimeRequest\x12T\n\x06header\x18\x01 \x01(\x0b\x32\x44.make87_messages_ros2.rolling.rmf_reservation_msgs.msg.RequestHeader\x12g\n\x0c\x61lternatives\x18\x02 \x03(\x0b\x32Q.make87_messages_ros2.rolling.rmf_reservation_msgs.msg.FlexibleTimeReservationAltb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_reservation_msgs.msg.flexible_time_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FLEXIBLETIMEREQUEST']._serialized_start=308
  _globals['_FLEXIBLETIMEREQUEST']._serialized_end=520
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/srv/get_plan.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import path_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_path__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/rtabmap_msgs/srv/get_plan.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.srv\x1a?make87_messages_ros2/jazzy/geometry_msgs/msg/pose_stamped.proto\x1a\x36make87_messages_ros2/jazzy/rtabmap_msgs/msg/path.proto\"\x7f\n\x0eGetPlanRequest\x12\x11\n\tgoal_node\x18\x01 \x01(\x05\x12G\n\x04goal\x18\x02 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.geometry_msgs.msg.PoseStamped\x12\x11\n\ttolerance\x18\x03 \x01(\x02\"R\n\x0fGetPlanResponse\x12?\n\x04plan\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.jazzy.rtabmap_msgs.msg.Pathb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.srv.get_plan_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETPLANREQUEST']._serialized_start=228
  _globals['_GETPLANREQUEST']._serialized_end=355
  _globals['_GETPLANRESPONSE']._serialized_start=357
  _globals['_GETPLANRESPONSE']._serialized_end=439
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/point_cloud_interfaces/msg/compressed_point_cloud2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.sensor_msgs.msg import point_field_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_point__field__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/jazzy/point_cloud_interfaces/msg/compressed_point_cloud2.proto\x12\x35make87_messages_ros2.jazzy.point_cloud_interfaces.msg\x1a<make87_messages_ros2/jazzy/sensor_msgs/msg/point_field.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xb6\x02\n\x15\x43ompressedPointCloud2\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0e\n\x06height\x18\x02 \x01(\r\x12\r\n\x05width\x18\x03 \x01(\r\x12\x46\n\x06\x66ields\x18\x04 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.sensor_msgs.msg.PointField\x12\x14\n\x0cis_bigendian\x18\x05 \x01(\x08\x12\x12\n\npoint_step\x18\x06 \x01(\r\x12\x10\n\x08row_step\x18\x07 \x01(\r\x12\x17\n\x0f\x63ompressed_data\x18\x08 \x03(\r\x12\x10\n\x08is_dense\x18\t \x01(\x08\x12\x0e\n\x06\x66ormat\x18\n \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.point_cloud_interfaces.msg.compressed_point_cloud2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMPRESSEDPOINTCLOUD2']._serialized_start=259
  _globals['_COMPRESSEDPOINTCLOUD2']._serialized_end=569
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.situational_graphs_reasoning_msgs.msg import keyframe_pb2 as _keyframe_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GraphKeyframes(_message.Message):
    __slots__ = ["header", "type", "robot", "keyframes"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ROBOT_FIELD_NUMBER: _ClassVar[int]
    KEYFRAMES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    type: str
    robot: str
    keyframes: _containers.RepeatedCompositeFieldContainer[_keyframe_pb2.Keyframe]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., type: _Optional[str] = ..., robot: _Optional[str] = ..., keyframes: _Optional[_Iterable[_Union[_keyframe_pb2.Keyframe, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_with_covariance_stamped_pb2 as _pose_with_covariance_stamped_pb2
from make87_messages_ros2.rolling.nav_msgs.msg import occupancy_grid_pb2 as _occupancy_grid_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetMapRequest(_message.Message):
    __slots__ = ["map", "initial_pose"]
    MAP_FIELD_NUMBER: _ClassVar[int]
    INITIAL_POSE_FIELD_NUMBER: _ClassVar[int]
    map: _occupancy_grid_pb2.OccupancyGrid
    initial_pose: _pose_with_covariance_stamped_pb2.PoseWithCovarianceStamped
    def __init__(self, map: _Optional[_Union[_occupancy_grid_pb2.OccupancyGrid, _Mapping]] = ..., initial_pose: _Optional[_Union[_pose_with_covariance_stamped_pb2.PoseWithCovarianceStamped, _Mapping]] = ...) -> None: ...

class SetMapResponse(_message.Message):
    __slots__ = ["success"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



from make87_messages_ros2.rolling.micro_ros_msgs.msg import entity_pb2 as _entity_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Node(_message.Message):
    __slots__ = ["node_namespace", "node_name", "entities"]
    NODE_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    NODE_NAME_FIELD_NUMBER: _ClassVar[int]
    ENTITIES_FIELD_NUMBER: _ClassVar[int]
    node_namespace: str
    node_name: str
    entities: _containers.RepeatedCompositeFieldContainer[_entity_pb2.Entity]
    def __init__(self, node_namespace: _Optional[str] = ..., node_name: _Optional[str] = ..., entities: _Optional[_Iterable[_Union[_entity_pb2.Entity, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GeoPoint(_message.Message):
    __slots__ = ["latitude", "longitude", "altitude"]
    LATITUDE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_FIELD_NUMBER: _ClassVar[int]
    ALTITUDE_FIELD_NUMBER: _ClassVar[int]
    latitude: float
    longitude: float
    altitude: float
    def __init__(self, latitude: _Optional[float] = ..., longitude: _Optional[float] = ..., altitude: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.novatel_gps_msgs.msg import novatel_message_header_pb2 as _novatel_message_header_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NovatelVelocity(_message.Message):
    __slots__ = ["header", "novatel_msg_header", "solution_status", "velocity_type", "latency", "age", "horizontal_speed", "track_ground", "vertical_speed"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NOVATEL_MSG_HEADER_FIELD_NUMBER: _ClassVar[int]
    SOLUTION_STATUS_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_TYPE_FIELD_NUMBER: _ClassVar[int]
    LATENCY_FIELD_NUMBER: _ClassVar[int]
    AGE_FIELD_NUMBER: _ClassVar[int]
    HORIZONTAL_SPEED_FIELD_NUMBER: _ClassVar[int]
    TRACK_GROUND_FIELD_NUMBER: _ClassVar[int]
    VERTICAL_SPEED_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    novatel_msg_header: _novatel_message_header_pb2.NovatelMessageHeader
    solution_status: str
    velocity_type: str
    latency: float
    age: float
    horizontal_speed: float
    track_ground: float
    vertical_speed: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., novatel_msg_header: _Optional[_Union[_novatel_message_header_pb2.NovatelMessageHeader, _Mapping]] = ..., solution_status: _Optional[str] = ..., velocity_type: _Optional[str] = ..., latency: _Optional[float] = ..., age: _Optional[float] = ..., horizontal_speed: _Optional[float] = ..., track_ground: _Optional[float] = ..., vertical_speed: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/lgsvl_msgs/msg/detection3_d.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import twist_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_twist__pb2
from make87_messages_ros2.rolling.lgsvl_msgs.msg import bounding_box3_d_pb2 as make87__messages__ros2_dot_rolling_dot_lgsvl__msgs_dot_msg_dot_bounding__box3__d__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/rolling/lgsvl_msgs/msg/detection3_d.proto\x12+make87_messages_ros2.rolling.lgsvl_msgs.msg\x1a:make87_messages_ros2/rolling/geometry_msgs/msg/twist.proto\x1a\x41make87_messages_ros2/rolling/lgsvl_msgs/msg/bounding_box3_d.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\x8d\x02\n\x0b\x44\x65tection3D\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\n\n\x02id\x18\x02 \x01(\r\x12\r\n\x05label\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\x02\x12H\n\x04\x62\x62ox\x18\x05 \x01(\x0b\x32:.make87_messages_ros2.rolling.lgsvl_msgs.msg.BoundingBox3D\x12G\n\x08velocity\x18\x06 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Twistb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.lgsvl_msgs.msg.detection3_d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DETECTION3D']._serialized_start=295
  _globals['_DETECTION3D']._serialized_end=564
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.jazzy.rc_common_msgs.msg import return_code_pb2 as _return_code_pb2
from make87_messages_ros2.jazzy.rc_reason_msgs.msg import compartment_pb2 as _compartment_pb2
from make87_messages_ros2.jazzy.rc_reason_msgs.msg import item_pb2 as _item_pb2
from make87_messages_ros2.jazzy.rc_reason_msgs.msg import item_model_pb2 as _item_model_pb2
from make87_messages_ros2.jazzy.rc_reason_msgs.msg import load_carrier_pb2 as _load_carrier_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DetectItemsRequest(_message.Message):
    __slots__ = ["pose_frame", "region_of_interest_id", "load_carrier_id", "load_carrier_compartment", "item_models", "robot_pose"]
    POSE_FRAME_FIELD_NUMBER: _ClassVar[int]
    REGION_OF_INTEREST_ID_FIELD_NUMBER: _ClassVar[int]
    LOAD_CARRIER_ID_FIELD_NUMBER: _ClassVar[int]
    LOAD_CARRIER_COMPARTMENT_FIELD_NUMBER: _ClassVar[int]
    ITEM_MODELS_FIELD_NUMBER: _ClassVar[int]
    ROBOT_POSE_FIELD_NUMBER: _ClassVar[int]
    pose_frame: str
    region_of_interest_id: str
    load_carrier_id: str
    load_carrier_compartment: _compartment_pb2.Compartment
    item_models: _containers.RepeatedCompositeFieldContainer[_item_model_pb2.ItemModel]
    robot_pose: _pose_pb2.Pose
    def __init__(self, pose_frame: _Optional[str] = ..., region_of_interest_id: _Optional[str] = ..., load_carrier_id: _Optional[str] = ..., load_carrier_compartment: _Optional[_Union[_compartment_pb2.Compartment, _Mapping]] = ..., item_models: _Optional[_Iterable[_Union[_item_model_pb2.ItemModel, _Mapping]]] = ..., robot_pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ...) -> None: ...

class DetectItemsResponse(_message.Message):
    __slots__ = ["timestamp", "items", "load_carriers", "return_code"]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    LOAD_CARRIERS_FIELD_NUMBER: _ClassVar[int]
    RETURN_CODE_FIELD_NUMBER: _ClassVar[int]
    timestamp: _time_pb2.Time
    items: _containers.RepeatedCompositeFieldContainer[_item_pb2.Item]
    load_carriers: _containers.RepeatedCompositeFieldContainer[_load_carrier_pb2.LoadCarrier]
    return_code: _return_code_pb2.ReturnCode
    def __init__(self, timestamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., items: _Optional[_Iterable[_Union[_item_pb2.Item, _Mapping]]] = ..., load_carriers: _Optional[_Iterable[_Union[_load_carrier_pb2.LoadCarrier, _Mapping]]] = ..., return_code: _Optional[_Union[_return_code_pb2.ReturnCode, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from make87_messages_ros2.humble.vision_msgs.msg import bounding_box3_d_pb2 as _bounding_box3_d_pb2
from make87_messages_ros2.humble.vision_msgs.msg import object_hypothesis_with_pose_pb2 as _object_hypothesis_with_pose_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Detection3D(_message.Message):
    __slots__ = ["header", "ros2_header", "results", "bbox", "id"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    BBOX_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    results: _containers.RepeatedCompositeFieldContainer[_object_hypothesis_with_pose_pb2.ObjectHypothesisWithPose]
    bbox: _bounding_box3_d_pb2.BoundingBox3D
    id: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., results: _Optional[_Iterable[_Union[_object_hypothesis_with_pose_pb2.ObjectHypothesisWithPose, _Mapping]]] = ..., bbox: _Optional[_Union[_bounding_box3_d_pb2.BoundingBox3D, _Mapping]] = ..., id: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.jazzy.rtabmap_msgs.msg import point2f_pb2 as _point2f_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class KeyPoint(_message.Message):
    __slots__ = ["pt", "size", "angle", "response", "octave", "class_id"]
    PT_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    ANGLE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    OCTAVE_FIELD_NUMBER: _ClassVar[int]
    CLASS_ID_FIELD_NUMBER: _ClassVar[int]
    pt: _point2f_pb2.Point2f
    size: float
    angle: float
    response: float
    octave: int
    class_id: int
    def __init__(self, pt: _Optional[_Union[_point2f_pb2.Point2f, _Mapping]] = ..., size: _Optional[float] = ..., angle: _Optional[float] = ..., response: _Optional[float] = ..., octave: _Optional[int] = ..., class_id: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/srv/command_ack.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/rolling/mavros_msgs/srv/command_ack.proto\x12,make87_messages_ros2.rolling.mavros_msgs.srv\"]\n\x11\x43ommandAckRequest\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\r\x12\x0e\n\x06result\x18\x02 \x01(\r\x12\x10\n\x08progress\x18\x03 \x01(\r\x12\x15\n\rresult_param2\x18\x04 \x01(\r\"5\n\x12\x43ommandAckResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06result\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.srv.command_ack_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMMANDACKREQUEST']._serialized_start=112
  _globals['_COMMANDACKREQUEST']._serialized_end=205
  _globals['_COMMANDACKRESPONSE']._serialized_start=207
  _globals['_COMMANDACKRESPONSE']._serialized_end=260
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PointOfInterestRequest(_message.Message):
    __slots__ = ["header", "name", "module_name", "request_id", "cancel", "update_num", "guid_valid", "guid", "tolerance"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    MODULE_NAME_FIELD_NUMBER: _ClassVar[int]
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    CANCEL_FIELD_NUMBER: _ClassVar[int]
    UPDATE_NUM_FIELD_NUMBER: _ClassVar[int]
    GUID_VALID_FIELD_NUMBER: _ClassVar[int]
    GUID_FIELD_NUMBER: _ClassVar[int]
    TOLERANCE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    name: str
    module_name: str
    request_id: int
    cancel: int
    update_num: int
    guid_valid: int
    guid: int
    tolerance: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., name: _Optional[str] = ..., module_name: _Optional[str] = ..., request_id: _Optional[int] = ..., cancel: _Optional[int] = ..., update_num: _Optional[int] = ..., guid_valid: _Optional[int] = ..., guid: _Optional[int] = ..., tolerance: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class BlockHeader(_message.Message):
    __slots__ = ["sync_1", "sync_2", "crc", "id", "revision", "length", "tow", "wnc"]
    SYNC_1_FIELD_NUMBER: _ClassVar[int]
    SYNC_2_FIELD_NUMBER: _ClassVar[int]
    CRC_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    LENGTH_FIELD_NUMBER: _ClassVar[int]
    TOW_FIELD_NUMBER: _ClassVar[int]
    WNC_FIELD_NUMBER: _ClassVar[int]
    sync_1: int
    sync_2: int
    crc: int
    id: int
    revision: int
    length: int
    tow: int
    wnc: int
    def __init__(self, sync_1: _Optional[int] = ..., sync_2: _Optional[int] = ..., crc: _Optional[int] = ..., id: _Optional[int] = ..., revision: _Optional[int] = ..., length: _Optional[int] = ..., tow: _Optional[int] = ..., wnc: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SubscribersRequest(_message.Message):
    __slots__ = ["topic"]
    TOPIC_FIELD_NUMBER: _ClassVar[int]
    topic: str
    def __init__(self, topic: _Optional[str] = ...) -> None: ...

class SubscribersResponse(_message.Message):
    __slots__ = ["subscribers"]
    SUBSCRIBERS_FIELD_NUMBER: _ClassVar[int]
    subscribers: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, subscribers: _Optional[_Iterable[str]] = ...) -> None: ...



from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IbeoDataHeader(_message.Message):
    __slots__ = ["previous_message_size", "message_size", "device_id", "data_type_id", "stamp"]
    PREVIOUS_MESSAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    previous_message_size: int
    message_size: int
    device_id: int
    data_type_id: int
    stamp: _time_pb2.Time
    def __init__(self, previous_message_size: _Optional[int] = ..., message_size: _Optional[int] = ..., device_id: _Optional[int] = ..., data_type_id: _Optional[int] = ..., stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/action_msgs/msg/goal_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.jazzy.unique_identifier_msgs.msg import uuid_pb2 as make87__messages__ros2_dot_jazzy_dot_unique__identifier__msgs_dot_msg_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/action_msgs/msg/goal_info.proto\x12*make87_messages_ros2.jazzy.action_msgs.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\x1a@make87_messages_ros2/jazzy/unique_identifier_msgs/msg/uuid.proto\"\xa0\x01\n\x08GoalInfo\x12L\n\x07goal_id\x18\x01 \x01(\x0b\x32;.make87_messages_ros2.jazzy.unique_identifier_msgs.msg.UUID\x12\x46\n\x05stamp\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Timeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.action_msgs.msg.goal_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GOALINFO']._serialized_start=235
  _globals['_GOALINFO']._serialized_end=395
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ds_dbw_msgs/msg/monitor_report.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/humble/ds_dbw_msgs/msg/monitor_report.proto\x12+make87_messages_ros2.humble.ds_dbw_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xf3\x0c\n\rMonitorReport\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\r\n\x05\x66\x61ult\x18\x03 \x01(\x08\x12\x0f\n\x07shutoff\x18\x04 \x01(\x08\x12\x19\n\x11shutoff_on_motion\x18\x05 \x01(\x08\x12\x12\n\nstationary\x18\x06 \x01(\x08\x12\x12\n\nfault_test\x18\x07 \x01(\r\x12\x14\n\x0c\x66\x61ult_system\x18\x08 \x01(\r\x12\x13\n\x0b\x66\x61ult_steer\x18\t \x01(\r\x12\x13\n\x0b\x66\x61ult_brake\x18\n \x01(\r\x12\x13\n\x0b\x66\x61ult_thrtl\x18\x0b \x01(\r\x12\x12\n\nfault_gear\x18\x0c \x01(\r\x12\x11\n\tfault_ulc\x18\r \x01(\r\x12\x1e\n\x16\x66\x61ult_vehicle_velocity\x18\x0e \x01(\r\x12\x1c\n\x14\x66\x61ult_steer_feedback\x18\x0f \x01(\r\x12\x19\n\x11\x66\x61ult_steer_input\x18\x10 \x01(\r\x12\x19\n\x11\x66\x61ult_steer_param\x18\x11 \x01(\r\x12\x19\n\x11\x66\x61ult_steer_limit\x18\x12 \x01(\r\x12\x1c\n\x14\x66\x61ult_steer_override\x18\x13 \x01(\r\x12\x17\n\x0f\x66\x61ult_steer_cmd\x18\x14 \x01(\r\x12\x1c\n\x14\x66\x61ult_steer_cmd_rate\x18\x15 \x01(\r\x12\x1a\n\x12\x66\x61ult_steer_cmd_en\x18\x16 \x01(\r\x12\x1b\n\x13\x66\x61ult_steer_cmd_sys\x18\x17 \x01(\r\x12\x1b\n\x13\x66\x61ult_steer_cmd_ovr\x18\x18 \x01(\r\x12\x1c\n\x14\x66\x61ult_brake_feedback\x18\x19 \x01(\r\x12\x19\n\x11\x66\x61ult_brake_input\x18\x1a \x01(\r\x12\x19\n\x11\x66\x61ult_brake_param\x18\x1b \x01(\r\x12\x19\n\x11\x66\x61ult_brake_limit\x18\x1c \x01(\r\x12\x1c\n\x14\x66\x61ult_brake_override\x18\x1d \x01(\r\x12\x17\n\x0f\x66\x61ult_brake_cmd\x18\x1e \x01(\r\x12\x1b\n\x13\x66\x61ult_brake_cmd_ulc\x18\x1f \x01(\r\x12\x1a\n\x12\x66\x61ult_brake_cmd_en\x18  \x01(\r\x12\x1b\n\x13\x66\x61ult_brake_cmd_sys\x18! \x01(\r\x12\x1b\n\x13\x66\x61ult_brake_cmd_ovr\x18\" \x01(\r\x12\x1c\n\x14\x66\x61ult_thrtl_feedback\x18# \x01(\r\x12\x19\n\x11\x66\x61ult_thrtl_input\x18$ \x01(\r\x12\x19\n\x11\x66\x61ult_thrtl_param\x18% \x01(\r\x12\x19\n\x11\x66\x61ult_thrtl_limit\x18& \x01(\r\x12\x1c\n\x14\x66\x61ult_thrtl_override\x18\' \x01(\r\x12\x17\n\x0f\x66\x61ult_thrtl_cmd\x18( \x01(\r\x12\x1b\n\x13\x66\x61ult_thrtl_cmd_ulc\x18) \x01(\r\x12\x1a\n\x12\x66\x61ult_thrtl_cmd_en\x18* \x01(\r\x12\x1b\n\x13\x66\x61ult_thrtl_cmd_sys\x18+ \x01(\r\x12\x1b\n\x13\x66\x61ult_thrtl_cmd_ovr\x18, \x01(\r\x12\x1b\n\x13\x66\x61ult_gear_feedback\x18- \x01(\r\x12\x18\n\x10\x66\x61ult_gear_input\x18. \x01(\r\x12\x18\n\x10\x66\x61ult_gear_param\x18/ \x01(\r\x12\x1b\n\x13\x66\x61ult_gear_override\x18\x30 \x01(\r\x12\x16\n\x0e\x66\x61ult_gear_cmd\x18\x31 \x01(\r\x12\x1a\n\x12\x66\x61ult_gear_cmd_ulc\x18\x32 \x01(\r\x12\x1a\n\x12\x66\x61ult_system_param\x18\x33 \x01(\r\x12\x1b\n\x13steer_cmd_match_oem\x18\x34 \x01(\x08\x12\x1b\n\x13steer_cmd_match_dbw\x18\x35 \x01(\x08\x12\x1b\n\x13\x62rake_cmd_match_oem\x18\x36 \x01(\x08\x12\x1b\n\x13\x62rake_cmd_match_dbw\x18\x37 \x01(\x08\x12\x1b\n\x13thrtl_cmd_match_oem\x18\x38 \x01(\x08\x12\x1b\n\x13thrtl_cmd_match_dbw\x18\x39 \x01(\x08\x12\x1a\n\x12gear_cmd_match_oem\x18: \x01(\x08\x12\x1a\n\x12gear_cmd_match_dbw\x18; \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ds_dbw_msgs.msg.monitor_report_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MONITORREPORT']._serialized_start=204
  _globals['_MONITORREPORT']._serialized_end=1855
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.vision_msgs.msg import point2_d_pb2 as _point2_d_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Pose2D(_message.Message):
    __slots__ = ["position", "theta"]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    THETA_FIELD_NUMBER: _ClassVar[int]
    position: _point2_d_pb2.Point2D
    theta: float
    def __init__(self, position: _Optional[_Union[_point2_d_pb2.Point2D, _Mapping]] = ..., theta: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.polygon_msgs.msg import point2_d_pb2 as _point2_d_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Polygon2D(_message.Message):
    __slots__ = ["points"]
    POINTS_FIELD_NUMBER: _ClassVar[int]
    points: _containers.RepeatedCompositeFieldContainer[_point2_d_pb2.Point2D]
    def __init__(self, points: _Optional[_Iterable[_Union[_point2_d_pb2.Point2D, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.example_interfaces.msg import multi_array_layout_pb2 as _multi_array_layout_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Float64MultiArray(_message.Message):
    __slots__ = ["layout", "data"]
    LAYOUT_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    layout: _multi_array_layout_pb2.MultiArrayLayout
    data: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, layout: _Optional[_Union[_multi_array_layout_pb2.MultiArrayLayout, _Mapping]] = ..., data: _Optional[_Iterable[float]] = ...) -> None: ...
